@@ -1,4 +1,3 @@
-from __future__ import unicode_literals
 import os
 from os.path import dirname
 import platform
@@ -7,11 +6,7 @@ import sys
 import tempfile
 from textwrap import dedent
 import unittest
-
-try:
-    from unittest.mock import MagicMock, patch
-except:
-    from mock import MagicMock, patch
+from unittest.mock import MagicMock, patch
 
 from green import loader
 from green.loader import GreenTestLoader, flattenTestSuite
@@ -23,7 +18,7 @@ class TestToProtoTestList(unittest.TestCase):
         toProtoTestList() raises import errors normally
         """
         suite = MagicMock()
-        suite.__class__.__name__ = str("ModuleImportFailure")
+        suite.__class__.__name__ = "ModuleImportFailure"
         suite.__str__.return_value = "exception_method (other_stuff)"
         suite.exception_method.side_effect = AttributeError
         self.assertRaises(AttributeError, loader.toProtoTestList, (suite,))
@@ -33,7 +28,7 @@ class TestToProtoTestList(unittest.TestCase):
         toProtoTestList() does not raise errors when doing completions
         """
         suite = MagicMock()
-        suite.__class__.__name__ = str("ModuleImportFailure")
+        suite.__class__.__name__ = "ModuleImportFailure"
         suite.__str__.return_value = "exception_method other_stuff"
         suite.exception_method.side_effect = AttributeError
         self.assertEqual(loader.toProtoTestList(suite, doing_completions=True), [])
@@ -41,12 +36,12 @@ class TestToProtoTestList(unittest.TestCase):
 
 class TestToParallelTargets(unittest.TestCase):
     def setUp(self):
-        super(TestToParallelTargets, self).setUp()
+        super().setUp()
 
-        class FakeModule(object):
+        class FakeModule:
             pass
 
-        class FakeModule2(object):
+        class FakeModule2:
             pass
 
         self._fake_module_name = "my_test_module"
@@ -57,7 +52,7 @@ class TestToParallelTargets(unittest.TestCase):
     def tearDown(self):
         del sys.modules[self._fake_module_name]
         del sys.modules[self._fake_module_name2]
-        super(TestToParallelTargets, self).tearDown()
+        super().tearDown()
 
     def test_methods_with_no_constraints(self):
         """
@@ -360,8 +355,8 @@ class TestLoadTestsFromTestCase(unittest.TestCase):
         suite = self.loader.loadTestsFromTestCase(Normal)
         self.assertEqual(suite.countTestCases(), 2)
         self.assertEqual(
-            set([x._testMethodName for x in suite._tests]),
-            set(["test_method1", "test_method2"]),
+            {x._testMethodName for x in suite._tests},
+            {"test_method1", "test_method2"},
         )
 
     def test_isTestCaseDisabled(self):
@@ -513,7 +508,6 @@ class TestDiscover(unittest.TestCase):
 
 
 class TestLoadTargets(unittest.TestCase):
-
     # Setup
     @classmethod
     def setUpClass(cls):
@@ -994,7 +988,6 @@ class TestLoadTargets(unittest.TestCase):
 
 
 class TestFlattenTestSuite(unittest.TestCase):
-
     # Setup
     @classmethod
     def setUpClass(cls):
