@@ -1,5 +1,3 @@
-# encoding: utf-8
-from __future__ import unicode_literals
 import copy
 
 # `from doctest import DocTestCase` causes crashes, since the DocTestCase is
@@ -11,6 +9,7 @@ from io import StringIO
 import sys
 import os
 import unittest
+from unittest.mock import MagicMock, patch
 import tempfile
 
 from green.config import default_args
@@ -24,21 +23,16 @@ from green.result import (
     BaseTestResult,
 )
 
-try:
-    from unittest.mock import MagicMock, patch
-except ImportError:
-    from mock import MagicMock, patch
-
 from coverage import coverage, CoverageException
 
 
-class MyProtoTest(ProtoTest, object):
+class MyProtoTest(ProtoTest):
     """
     For quickly making a ProtoTest
     """
 
     def __init__(self):
-        super(MyProtoTest, self).__init__()
+        super().__init__()
         self.module = "my_module"
         self.class_name = "MyClass"
         self.method_name = "myMethod"
@@ -264,6 +258,7 @@ class TestProtoTest(unittest.TestCase):
         """
         getDescription() returns what we expect for all verbose levels
         """
+
         # With a docstring
         class Fruit(unittest.TestCase):
             def test_stuff(self):
@@ -945,7 +940,7 @@ class TestGreenTestResultAdds(unittest.TestCase):
         test = proto_test(MagicMock())
         reason = "Twisted is odd"
         err = proto_error(err)
-        err.traceback_lines = ["UnsupportedTrialFeature: ('skip', '{}')".format(reason)]
+        err.traceback_lines = [f"UnsupportedTrialFeature: ('skip', '{reason}')"]
         self.gtr.addFailure(test, err)
         self.gtr._reportOutcome.assert_called_with(
             test, "s", self.gtr.colors.skipped, reason=reason
