@@ -1,4 +1,3 @@
-from __future__ import unicode_literals
 import copy
 from io import StringIO
 import os
@@ -9,6 +8,7 @@ import sys
 import tempfile
 from textwrap import dedent
 import unittest
+from unittest.mock import MagicMock
 import weakref
 
 from green.config import default_args
@@ -18,11 +18,6 @@ from green.output import GreenStream
 from green.runner import InitializerOrFinalizer, run
 from green.suite import GreenTestSuite
 
-try:
-    from unittest.mock import MagicMock
-except:
-    from mock import MagicMock
-
 
 global skip_testtools
 skip_testtools = False
@@ -155,9 +150,7 @@ class TestRun(unittest.TestCase):
             class Verbose3(unittest.TestCase):
                 def test01(self):
                     pass
-            """.format(
-                    os.getpid()
-                )
+            """
             )
         )
         fh.close()
@@ -183,9 +176,7 @@ class TestRun(unittest.TestCase):
             class Warnings(unittest.TestCase):
                 def test01(self):
                     pass
-            """.format(
-                    os.getpid()
-                )
+            """
             )
         )
         fh.close()
@@ -218,9 +209,7 @@ class TestRun(unittest.TestCase):
             class Failed(unittest.TestCase):
                 def test01(self):
                     self.assertTrue(False)
-            """.format(
-                    os.getpid()
-                )
+            """
             )
         )
         fh.close()
@@ -246,9 +235,7 @@ class TestRun(unittest.TestCase):
                     raise Exception
                 def test01(self):
                     pass
-            """.format(
-                    os.getpid()
-                )
+            """
             )
         )
         fh.close()
@@ -274,9 +261,7 @@ class TestRun(unittest.TestCase):
                     raise SystemExit(1)
                 def test01(self):
                     pass
-            """.format(
-                    os.getpid()
-                )
+            """
             )
         )
         fh.close()
@@ -288,7 +273,6 @@ class TestRun(unittest.TestCase):
 
 
 class TestProcesses(unittest.TestCase):
-
     # Setup
     @classmethod
     def setUpClass(cls):
